==> tccli-3.0.1051.1-py2.py3-none-any.whl: tccli/examples/waf/v20180125/DescribeUserDomainInfo.md <==
**Example 1: 查询saas和clb域名信息**



Input: 

```
tccli waf DescribeUserDomainInfo --cli-unfold-argument ```

Output: 
```
{
    "Response": {
        "RequestId": "b4f13899-561b-46a0-a045-6ba6b72c38f2",
        "UsersInfo": [
            {
                "Appid": 251197211,
                "Domain": "2333.douban.com",
                "DomainId": "45bdad0d-bb98-4cb3-8e5a-ab6e2992",
                "InstanceId": "Swaf_0000001g0",
                "InstanceName": "",
                "Edition": "",
                "Level": 1,
                "WriteConfig": {
                    "EnableHeaders": 1,
                    "EnableBody": 1
                }
            },
            {
                "Appid": 251197211,
                "Domain": "engine_test_dev2.qcloudwaf.com",
                "DomainId": "205eeb7e-1a5c-4f54-aec9-00c97d49",
                "InstanceId": "",
                "InstanceName": "",
                "Edition": "",
                "Level": 1,
                "WriteConfig": {
                    "EnableHeaders": 1,
                    "EnableBody": 1
                }
            },
            {
                "Appid": 251197211,
                "Domain": "qqq.douban.com",
                "DomainId": "b1c1b45b-560e-497e-8c48-f37f7a4f",
                "InstanceId": "",
                "InstanceName": "",
                "Edition": "",
                "Level": 1,
                "WriteConfig": {
                    "EnableHeaders": 1,
                    "EnableBody": 1
                }
            },
            {
                "Appid": 251197211,
                "Domain": "aaa.douban.com",
                "DomainId": "4d8a565e-c982-4172-b10c-6ed1cc5e",
                "InstanceId": "",
                "InstanceName": "",
                "Edition": "",
                "Level": 1,
                "WriteConfig": {
                    "EnableHeaders": 1,
                    "EnableBody": 1
                }
            },
            {
                "Appid": 251197211,
                "Domain": "bbb.douban.com",
                "DomainId": "d0fae8cc-76b6-4db1-af62-9dd9816d",
                "InstanceId": "",
                "InstanceName": "",
                "Edition": "",
                "Level": 1,
                "WriteConfig": {
                    "EnableHeaders": 1,
                    "EnableBody": 1
                }
            },
            {
                "Appid": 251197211,
                "Domain": "ccc.douban.com",
                "DomainId": "409b0b1b-e076-403e-ad63-a7378d32",
                "InstanceId": "",
                "InstanceName": "",
                "Edition": "",
                "Level": 1,
                "WriteConfig": {
                    "EnableHeaders": 1,
                    "EnableBody": 1
                }
            },
            {
                "Appid": 251197211,
                "Domain": "ddd.douban.com",
                "DomainId": "b3be79b3-8c96-4797-8658-7d9286de",
                "InstanceId": "",
                "InstanceName": "",
                "Edition": "",
                "Level": 1,
                "WriteConfig": {
                    "EnableHeaders": 1,
                    "EnableBody": 1
                }
            },
            {
                "Appid": 251197211,
                "Domain": "eee.douban.com",
                "DomainId": "302363db-b7d6-4a0f-95e4-66fbc9c7",
                "InstanceId": "",
                "InstanceName": "",
                "Edition": "",
                "Level": 1,
                "WriteConfig": {
                    "EnableHeaders": 1,
                    "EnableBody": 1
                }
            },
            {
                "Appid": 251197211,
                "Domain": "ccc1.douban.com",
                "DomainId": "305a396b-2089-4bac-a22e-9e160d4a",
                "InstanceId": "Swaf_0000001g0",
                "InstanceName": "",
                "Edition": "",
                "Level": 1,
                "WriteConfig": {
                    "EnableHeaders": 1,
                    "EnableBody": 1
                }
            },
            {
                "Appid": 251197211,
                "Domain": "fff.douban.com",
                "DomainId": "cd50958d-3644-49bc-9336-196292a2",
                "InstanceId": "Swaf_0000001g0",
                "InstanceName": "",
                "Edition": "",
                "Level": 1,
                "WriteConfig": {
                    "EnableHeaders": 1,
                    "EnableBody": 1
                }
            },
            {
                "Appid": 251197211,
                "Domain": "engine_test_dev2.qcloudwaf.com",
                "DomainId": "dff0ab09-ca25-4b32-951a-fb94b563",
                "InstanceId": "Swaf_0000001g0",
                "InstanceName": "",
                "Edition": "",
                "Level": 1,
                "WriteConfig": {
                    "EnableHeaders": 1,
                    "EnableBody": 1
                }
            },
            {
                "Appid": 251197211,
                "Domain": "enginedev2.qcloudwaf.com",
                "DomainId": "1856c74a-7237-44e9-9bec-ca3210d4",
                "InstanceId": "Swaf_0000001g0",
                "InstanceName": "",
                "Edition": "",
                "Level": 1,
                "WriteConfig": {
                    "EnableHeaders": 1,
                    "EnableBody": 1
                }
            },
            {
                "Appid": 251197211,
                "Domain": "edge.testwaf.com",
                "DomainId": "566f72c5-f6c4-4510-b680-57fa3e71",
                "InstanceId": "Swaf_0000001g0",
                "InstanceName": "",
                "Edition": "",
                "Level": 1,
                "WriteConfig": {
                    "EnableHeaders": 1,
                    "EnableBody": 1
                }
            },
            {
                "Appid": 251197211,
                "Domain": "gu.testwaf.com",
                "DomainId": "cfce976e-312b-4bce-817d-b5d9d3b0",
                "InstanceId": "Swaf_0000001g0",
                "InstanceName": "",
                "Edition": "",
                "Level": 1,
                "WriteConfig": {
                    "EnableHeaders": 1,
                    "EnableBody": 1
                }
            },
            {
                "Appid": 251197211,
                "Domain": "v4.testwaf.com",
                "DomainId": "157a0692-cb34-46ba-b094-ee2d38fe",
                "InstanceId": "Swaf_0000001g0",
                "InstanceName": "",
                "Edition": "",
                "Level": 1,
                "WriteConfig": {
                    "EnableHeaders": 1,
                    "EnableBody": 1
                }
            },
            {
                "Appid": 251197211,
                "Domain": "yuming.testwaf.com",
                "DomainId": "d6c9ae97-6cfd-45f9-a977-eb6dffcd",
                "InstanceId": "Swaf_0000001g0",
                "InstanceName": "",
                "Edition": "",
                "Level": 1,
                "WriteConfig": {
                    "EnableHeaders": 1,
                    "EnableBody": 1
                }
            },
            {
                "Appid": 251197211,
                "Domain": "34ttt.qcloudwaf.com",
                "DomainId": "a7be4d31-a9eb-4305-9cd4-598c9282",
                "InstanceId": "",
                "InstanceName": "",
                "Edition": "",
                "Level": 1,
                "WriteConfig": {
                    "EnableHeaders": 1,
                    "EnableBody": 1
                }
            },
            {
                "Appid": 251197211,
                "Domain": "hz-test.qcloudwaf.com",
                "DomainId": "0e37c944-f2d8-4fa1-922b-1e9373fe",
                "InstanceId": "",
                "InstanceName": "",
                "Edition": "",
                "Level": 1,
                "WriteConfig": {
                    "EnableHeaders": 1,
                    "EnableBody": 1
                }
            },
            {
                "Appid": 251197211,
                "Domain": "linan.douban.com",
                "DomainId": "ec0d6c46-804c-4d30-8a45-fc876dc7",
                "InstanceId": "",
                "InstanceName": "",
                "Edition": "",
                "Level": 1,
                "WriteConfig": {
                    "EnableHeaders": 1,
                    "EnableBody": 1
                }
            },
            {
                "Appid": 251197211,
                "Domain": "linan.baidu.com",
                "DomainId": "4cbb2110-2dca-4077-8a4d-317c2c71",
                "InstanceId": "",
                "InstanceName": "",
                "Edition": "",
                "Level": 1,
                "WriteConfig": {
                    "EnableHeaders": 1,
                    "EnableBody": 1
                }
            },
            {
                "Appid": 251197211,
                "Domain": "zzy.baidu.com",
                "DomainId": "3b6795b8-a3b2-45f5-a1a8-4d96bb7a",
                "InstanceId": "",
                "InstanceName": "",
                "Edition": "",
                "Level": 1,
                "WriteConfig": {
                    "EnableHeaders": 1,
                    "EnableBody": 1
                }
            },
            {
                "Appid": 251197211,
                "Domain": "moya.douban.com",
                "DomainId": "c5f5020c-1cc1-4ed1-aa6b-9d01c2f4",
                "InstanceId": "yuyuyuyuyu",
                "InstanceName": "ModifyName",
                "Edition": "sparta-waf",
                "Level": 1,
                "WriteConfig": {
                    "EnableHeaders": 1,
                    "EnableBody": 1
                }
            },
            {
                "Appid": 251197211,
                "Domain": "testzy8.qcloudwaf.com",
                "DomainId": "2d5913d5-27e0-48cf-beee-df9cf8ea",
                "InstanceId": "yuyuyuyuyu",
                "InstanceName": "ModifyName",
                "Edition": "sparta-waf",
                "Level": 1,
                "WriteConfig": {
                    "EnableHeaders": 1,
                    "EnableBody": 1
                }
            },
            {
                "Appid": 251197211,
                "Domain": "cc324.qcloudwaf.com",
                "DomainId": "0f010d94-1896-40b7-a564-99bf53ea",
                "InstanceId": "yuyuyuyuyu",
                "InstanceName": "ModifyName",
                "Edition": "sparta-waf",
                "Level": 1,
                "WriteConfig": {
                    "EnableHeaders": 1,
                    "EnableBody": 1
                }
            },
            {
                "Appid": 251197211,
                "Domain": "www.baidu.com",
                "DomainId": "dc925172-3254-4abd-8df5-b2c8601a",
                "InstanceId": "yuyuyuyuyu",
                "InstanceName": "ModifyName",
                "Edition": "sparta-waf",
                "Level": 1,
                "WriteConfig": {
                    "EnableHeaders": 1,
                    "EnableBody": 1
                }
            },
            {
                "Appid": 251197211,
                "Domain": "tbbbb.qcloudwaf.com",
                "DomainId": "100993c0-cce8-4e50-a80d-b793aae2",
                "InstanceId": "yuyuyuyuyu",
                "InstanceName": "ModifyName",
                "Edition": "sparta-waf",
                "Level": 1,
                "WriteConfig": {
                    "EnableHeaders": 1,
                    "EnableBody": 1
                }
            },
            {
                "Appid": 251197211,
                "Domain": "ccfh325.qcloudwaf.com",
                "DomainId": "565595f3-17eb-4211-95ac-a4caf780",
                "InstanceId": "yuyuyuyuyu",
                "InstanceName": "ModifyName",
                "Edition": "sparta-waf",
                "Level": 1,
                "WriteConfig": {
                    "EnableHeaders": 1,
                    "EnableBody": 1
                }
            },
            {
                "Appid": 251197211,
                "Domain": "ccfh325001.qcloudwaf.com",
                "DomainId": "060387d5-c949-41f2-bdad-d79987b3",
                "InstanceId": "yuyuyuyuyu",
                "InstanceName": "ModifyName",
                "Edition": "sparta-waf",
                "Level": 1,
                "WriteConfig": {
                    "EnableHeaders": 1,
                    "EnableBody": 1
                }
            },
            {
                "Appid": 251197211,
                "Domain": "tba.qcloudwaf.com",
                "DomainId": "44eabe86-6dbc-424e-9453-02c4e283",
                "InstanceId": "yuyuyuyuyu",
                "InstanceName": "ModifyName",
                "Edition": "sparta-waf",
                "Level": 1,
                "WriteConfig": {
                    "EnableHeaders": 1,
                    "EnableBody": 1
                }
            },
            {
                "Appid": 251197211,
                "Domain": "thank001.qcloudwaf.com",
                "DomainId": "4c038bce-88ba-4780-b76f-1964fc26",
                "InstanceId": "yuyuyuyuyu",
                "InstanceName": "ModifyName",
                "Edition": "sparta-waf",
                "Level": 1,
                "WriteConfig": {
                    "EnableHeaders": 1,
                    "EnableBody": 1
                }
            },
            {
                "Appid": 251197211,
                "Domain": "thank002.qcloudwaf.com",
                "DomainId": "9323bed4-996f-4b3c-b180-328d2353",
                "InstanceId": "yuyuyuyuyu",
                "InstanceName": "ModifyName",
                "Edition": "sparta-waf",
                "Level": 1,
                "WriteConfig": {
                    "EnableHeaders": 1,
                    "EnableBody": 1
                }
            },
            {
                "Appid": 251197211,
                "Domain": "testzy9.qcloudwaf.com",
                "DomainId": "d7d8fa3a-554a-449d-b7a2-378a12ac",
                "InstanceId": "waf_2kuf324o004y16zv",
                "InstanceName": "",
                "Edition": "",
                "Level": 1,
                "WriteConfig": {
                    "EnableHeaders": 1,
                    "EnableBody": 1
                }
            },
            {
                "Appid": 251197211,
                "Domain": "testzy10.qcloudwaf.com",
                "DomainId": "37df8cd6-9be6-4ddd-8431-92e644a9",
                "InstanceId": "waf_2kuf324o004y16zv",
                "InstanceName": "",
                "Edition": "",
                "Level": 1,
                "WriteConfig": {
                    "EnableHeaders": 1,
                    "EnableBody": 1
                }
            },
            {
                "Appid": 251197211,
                "Domain": "testnum.qcloudwaf.com",
                "DomainId": "55a5b674-0faa-462d-b329-f9167c58",
                "InstanceId": "waf_2kuf324o004y16zv",
                "InstanceName": "",
                "Edition": "",
                "Level": 1,
                "WriteConfig": {
                    "EnableHeaders": 1,
                    "EnableBody": 1
                }
            },
            {
                "Appid": 251197211,
                "Domain": "qbtestqq.qcloudwaf.com",
                "DomainId": "453e3ba3-03a1-4d27-af72-5d9e3047",
                "InstanceId": "yuyuyuyuyu",
                "InstanceName": "ModifyName",
                "Edition": "sparta-waf",
                "Level": 1,
                "WriteConfig": {
                    "EnableHeaders": 1,
                    "EnableBody": 1
                }
            },
            {
                "Appid": 251197211,
                "Domain": "qbtestya.qcloudwaf.com",
                "DomainId": "761214a4-e5f1-49ea-bbc5-d2e4ac9d",
                "InstanceId": "yuyuyuyuyu",
                "InstanceName": "ModifyName",
                "Edition": "sparta-waf",
                "Level": 1,
                "WriteConfig": {
                    "EnableHeaders": 1,
                    "EnableBody": 1
                }
            },
            {
                "Appid": 251197211,
                "Domain": "412001.qcloudwaf.com",
                "DomainId": "cc48116a897853859bdf5bab5c9e885a",
                "InstanceId": "yuyuyuyuyu",
                "InstanceName": "ModifyName",
                "Edition": "sparta-waf",
                "Level": 1,
                "WriteConfig": {
                    "EnableHeaders": 1,
                    "EnableBody": 1
                }
            },
            {
                "Appid": 251197211,
                "Domain": "413001.qcloudwaf.com",
                "DomainId": "c6458fdaa4bf5045bf069c2b549b5f08",
                "InstanceId": "yuyuyuyuyu",
                "InstanceName": "ModifyName",
                "Edition": "sparta-waf",
                "Level": 1,
                "WriteConfig": {
                    "EnableHeaders": 1,
                    "EnableBody": 1
                }
            }
        ]
    }
}
```

==> tccli-3.0.1073.1-py2.py3-none-any.whl: tccli/examples/waf/v20180125/DescribeUserDomainInfo.md <==
**Example 1: 查询saas和clb域名信息**



Input: 

```
tccli waf DescribeUserDomainInfo --cli-unfold-argument ```

Output: 
```
{
    "Response": {
        "RequestId": "b4f13899-561b-46a0-a045-6ba6b72c38f2",
        "UsersInfo": [
            {
                "Appid": 251197211,
                "Domain": "2333.douban.com",
                "DomainId": "45bdad0d-bb98-4cb3-8e5a-ab6e2992",
                "InstanceId": "Swaf_0000001g0",
                "InstanceName": "",
                "Edition": "",
                "Level": "1",
                "WriteConfig": "{\"EnableHeaders\": 1,\"EnableBody\": 1}",
                "Cls": 0,
                "CloudType": ""
            },
            {
                "Appid": 251197211,
                "Domain": "engine_test_dev2.qcloudwaf.com",
                "DomainId": "205eeb7e-1a5c-4f54-aec9-00c97d49",
                "InstanceId": "abc",
                "InstanceName": "",
                "Edition": "",
                "Level": "4",
                "WriteConfig": "{\"EnableBody\": 0}",
                "Cls": 1,
                "CloudType": ""
            },
            {
                "Appid": 251197211,
                "Domain": "413001.qcloudwaf.com",
                "DomainId": "c6458fdaa4bf5045bf069c2b549b5f08",
                "InstanceId": "yuyuyuyuyu",
                "InstanceName": "ModifyName",
                "Edition": "sparta-waf",
                "Level": "1",
                "WriteConfig": "{\"EnableHeaders\": 1,\"EnableBody\": 1}",
                "Cls": 0,
                "CloudType": ""
            }
        ]
    }
}
```
